--------------------
# LICENSE FOR USE 

model21cm
Copyright (C) 2019  I. Davenport, N. DePorzio

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/gpl/>.
 
--------------------

# PHYS 201: Data Analysis for Physicists
## Final Project

Authors: I. Davenport, N. DePorzio
Package Name: model21cm


This package infers the parameters for a model consisting of three parts: 

* The emission of 21cm light emitted from an excited state of interstallar hydrogen that has propagated according to cosmological models to an observer on Earth
* The affect of astrophysical foregrounds on the 21cm signal described above
* A noise term additional to the two affects above

 
